@@ -68,15 +68,15 @@ void Highlighter::htmlBrackets (const QString &text, const int start)
 
     int bn = currentBlock().blockNumber();
     bool mainFormatting (bn >= startCursor.blockNumber() && bn <= endCursor.blockNumber());
-    bool hugeLine (text.length() > 50000);
+    //bool hugeText (text.length() > 50000);
     int firstBraIndex = braIndex; // to check progress in the following loop
     while (braIndex >= 0)
     {
-        if (hugeLine)
+        /*if (hugeText)
         {
             setFormat (braIndex, text.length() - braIndex, translucentFormat);
             break;
-        }
+        }*/
         int braEndIndex;
 
         int matched = 0;
@@ -143,7 +143,7 @@ void Highlighter::htmlBrackets (const QString &text, const int start)
             if (quoteIndex >= braIndex && quoteIndex <= endLimit)
             {
                 /* ... distinguish between double and single quotes */
-                if (quoteIndex == text.indexOf (quoteMark, quoteIndex))
+                if (text.at (quoteIndex) == quoteMark.pattern().at (0))
                 {
                     quoteExpression = quoteMark;
                     quote = currentBlockState() == htmlStyleState ? htmlStyleDoubleQuoteState
@@ -175,7 +175,7 @@ void Highlighter::htmlBrackets (const QString &text, const int start)
             {
                 /* ... distinguish between double and single quotes
                    again because the quote mark may have changed */
-                if (quoteIndex == text.indexOf (quoteMark, quoteIndex))
+                if (text.at (quoteIndex) == quoteMark.pattern().at (0))
                 {
                     quoteExpression = quoteMark;
                     quote = currentBlockState() == htmlStyleState ? htmlStyleDoubleQuoteState
@@ -383,7 +383,7 @@ void Highlighter::htmlCSSHighlighter (const QString &text, const int start)
         setFormat (cssIndex + matched, text.length() - cssIndex - matched, neutralFormat);
         setCurrentBlockState (0);
 
-        /* ... and apply the css formats */;
+        /* ... and apply the css formats */
         multiLineQuote (text, cssIndex + matched, htmlCSSCommentState);
         int cssIndx = cssHighlighter (text, mainFormatting, cssIndex + matched);
         multiLineComment (text,
@@ -531,7 +531,7 @@ void Highlighter::htmlJavascript (const QString &text)
                           commentStartExpression, commentEndExpression,
                           htmlJavaCommentState,
                           commentFormat);
-        multiLineJSRegex (text, javaIndex + matched);
+        multiLineRegex (text, javaIndex + matched);
         if (mainFormatting)
         {
             for (const HighlightingRule &rule : qAsConst(highlightingRules))
@@ -547,7 +547,7 @@ void Highlighter::htmlJavascript (const QString &text)
                     while (index >= 0
                            && (fi == quoteFormat || fi == altQuoteFormat || fi == urlInsideQuoteFormat
                                || fi == commentFormat || fi == urlFormat
-                               || fi ==  JSRegexFormat))
+                               || fi ==  regexFormat))
                     {
                         index = text.indexOf (rule.pattern, index + match.capturedLength(), &match);
                         fi = format (index);
@@ -565,7 +565,7 @@ void Highlighter::htmlJavascript (const QString &text)
                         while (index >= 0
                                && (fi == quoteFormat || fi == altQuoteFormat || fi == urlInsideQuoteFormat
                                    || fi == commentFormat || fi == urlFormat
-                                   || fi == JSRegexFormat))
+                                   || fi == regexFormat))
                         {
                             index = text.indexOf (rule.pattern, index + match.capturedLength(), &match);
                             fi = format (index);
@@ -590,7 +590,7 @@ void Highlighter::htmlJavascript (const QString &text)
         while (javaEndIndex > -1
                && (fi == quoteFormat || fi == altQuoteFormat || fi == urlInsideQuoteFormat
                    || fi == commentFormat || fi == urlFormat
-                   || fi == JSRegexFormat))
+                   || fi == regexFormat))
         {
             javaEndIndex = text.indexOf (javaEndExp, javaEndIndex + endMatch.capturedLength(), &endMatch);
             fi = format (javaEndIndex);
