@@ -36,14 +36,24 @@ void FPwin::toggleSyntaxHighlighting()
     int count = ui->tabWidget->count();
     if (count == 0) return;
 
+    bool enableSH = ui->actionSyntax->isChecked();
+    if (enableSH)
+        waitToMakeBusy(); // it may take a while with huge texts
+
     for (int i = 0; i < count; ++i)
     {
         TextEdit *textEdit = qobject_cast< TabPage *>(ui->tabWidget->widget (i))->textEdit();
-        syntaxHighlighting (textEdit, ui->actionSyntax->isChecked(), textEdit->getLang());
+        syntaxHighlighting (textEdit, enableSH, textEdit->getLang());
     }
 
     if (QToolButton *langButton = ui->statusBar->findChild<QToolButton *>("langButton"))
-        langButton->setEnabled (ui->actionSyntax->isChecked());
+        langButton->setEnabled (enableSH);
+
+    if (enableSH)
+    {
+        QCoreApplication::processEvents();
+        unbusy();
+    }
 }
 /*************************/
 // Never returns an empty string; falls back to "url".
@@ -173,7 +183,7 @@ void FPwin::setProgLang (TextEdit *textEdit)
                 progLan = "ruby";
             else if (mime == "text/x-lua")
                 progLan = "lua";
-            else if (mime == "text/x-python")
+            else if (mime.startsWith("text/x-python")) // it may be "text/x-python3"
                 progLan = "python";
             else if (mime == "application/x-perl")
                 progLan = "perl";
@@ -191,7 +201,7 @@ void FPwin::setProgLang (TextEdit *textEdit)
                      || mime == "application/x-docbook+xml" || mime == "application/x-xbel" || mime == "text/feathernotes-fnx"
                      || mime == "text/vnd.trolltech.linguist" || mime == "text/x-opml+xml"
                      || mime == "application/xspf+xml" || mime == "audio/x-ms-asx"
-                     || mime == "application/vnd.kde.kxmlguirc" || mime == "application/vnd.google-earth.kml+xml")
+                     || mime == "application/vnd.kde.kxmlguirc" || mime == "application/vnd.google-earth.kml+xml" || mime == "application/vnd.kde.kcfg")
                 progLan = "xml";
             else if (mime == "text/css")
                 progLan = "css";
@@ -201,7 +211,7 @@ void FPwin::setProgLang (TextEdit *textEdit)
                 progLan = "changelog";
             else if (mime == "application/x-desktop")
                 progLan = "desktop";
-            else if (mime == "audio/x-scpls")
+            else if (mime == "audio/x-scpls" || mime == "application/vnd.kde.kcfgc")
                 progLan = "config";
             else if (mime == "application/javascript")
                 progLan = "javascript";
@@ -221,7 +231,7 @@ void FPwin::setProgLang (TextEdit *textEdit)
                 progLan = "html";
             else if (mime == "text/markdown")
                 progLan = "markdown";
-            else if (mime == "audio/x-mpegurl")
+            else if (mime == "audio/x-mpegurl" || mime == "application/vnd.apple.mpegurl")
                 progLan = "m3u";
             else if (fname.endsWith (".conf") || fname.endsWith (".ini"))
                  progLan = "config"; // only if the mime type isn't found
